@@ -49,11 +49,10 @@ cumsum_reset <- function(x, y = as.integer(x)) {
 # nocov start
 cumsum_reset_where <- function(where, y, .parent_nframes = 1L) {
   sexpr <- substitute(where)
-  isBinaryW <- is_binary_sexp(sexpr, .parent_nframes = .parent_nframes + 1L)
-  if (isBinaryW) {
+  if (length(sexpr) == 3L) {
     x <- eval.parent(sexpr[[2]], n = .parent_nframes)
-    o <- attr(isBinaryW, "M")
-    rhs_eval <- attr(isBinaryW, "rhs_eval")
+    o <- op2M(as.character(sexpr[[1]]))
+    rhs_eval <- eval.parent(sexpr[[3]], n = .parent_nframes)
     ans <- .Call("Ccumsum_reset_where", x, y, o, rhs_eval, PACKAGE = packageName)
     if (!is.null(ans)) {
       return(ans)
