@@ -10,6 +10,12 @@
 #' returns the index of the first element in \code{x} found in \code{table};
 #' if negative, returns the last element in \code{x} found in \code{table}.
 #'
+#' @param .raw \code{integer(1)}
+#' \describe{
+#' \item{0}{Return integer or logical as required.}
+#' \item{1}{Return raw if possible.}
+#' }
+#'
 #' @examples
 #' x <- c(1L, 4:5)
 #' y <- c(2L, 4:5)
@@ -18,47 +24,90 @@
 #' finp(x, y)
 #'
 #' @export
-fmatchp <- function(x, table, nomatch = NA_integer_, nThread = getOption("hutilscpp.nThread", 1L), fin = FALSE,
-                    whichFirst = 0L) {
+fmatchp <- function(x, table, nomatch = NA_integer_,
+                    nThread = getOption("hutilscpp.nThread", 1L),
+                    fin = FALSE,
+                    whichFirst = 0L,
+                    .raw = 0L) {
   nThread <- check_omp(nThread)
+  if (is.logical(x)) {
+    ans <- .Call("fmatchp_lgl", x, as.logical(table), nThread, fin, PACKAGE = "hutilscpp")
+    if (is.null(ans)) {
+      return(match_last_resort(x, table, nomatch, nThread, fin, whichFirst)) # nocov
+    }
+    if (is.na(nomatch) && is.integer(ans)) {
+      .Call("Cuncoalesce0", ans, PACKAGE = "hutilscpp")
+    }
+    return(ans)
+  }
   stopifnot(is.integer(nomatch))
   check_TF(fin)
   if (!is.symbol(substitute(table))) {
     # avoid constants
     table <- copy(table)
   }
-  .Call("fmatch", x, table, nomatch, fin, whichFirst, nThread, PACKAGE = packageName) %||%
-    match_last_resort(x, table, nomatch, nThread, fin, whichFirst) # nocov
+  ans <- .Call("fmatch", x, table, nomatch, fin, whichFirst, nThread, PACKAGE = packageName)
+  if (is.null(ans)) {
+    return(match_last_resort(x, table, nomatch, nThread, fin, whichFirst)) # nocov
+  }
+  ans
+
 }
 
 #' @rdname fmatchp
 #' @export
-finp <- function(x, table, nThread = getOption("hutilscpp.nThread", 1L)) {
+finp <- function(x, table, nThread = getOption("hutilscpp.nThread", 1L),
+                 .raw = 0L) {
   nThread <- check_omp(nThread)
   if (!is.symbol(substitute(table))) {
     # avoid constants
     table <- copy(table)
   }
-  fmatchp(x, table, nomatch = 0L, nThread = nThread, fin = TRUE)
+  if (is_seq(table)) {
+    ans <- .Call("Cors",
+                 "%between%", x, table[c(1L, length(table))],
+                 NULL, NULL, NULL,
+                 nThread,
+                 PACKAGE = "hutilscpp")
+    if (!is.null(ans)) {
+      return(raw2lgl(ans))
+    }
+  }
+
+  ans <- fmatchp(x, table, nomatch = 0L, nThread = nThread, fin = TRUE)
+  if (.raw) {
+    return(ans)
+  }
+  raw2lgl(ans)
 }
 
 #' @rdname fmatchp
 #' @export
-fnotinp <- function(x, table, nThread = getOption("hutilscpp.nThread", 1L)) {
+fnotinp <- function(x, table, nThread = getOption("hutilscpp.nThread", 1L),
+                    .raw = 0L) {
   nThread <- check_omp(nThread)
   if (!is.symbol(substitute(table))) {
     # avoid constants
     table <- copy(table)
   }
   ans <- fmatchp(x, table, nomatch = 0L, nThread = nThread, fin = TRUE)
-  FLIP(ans);
+  if (.raw) {
+    return(FLIP(ans))
+  }
+  raw2lgl(FLIP(ans))
+
 }
-FLIP <- `!`
+FLIP <- function(x) {
+  .Call("C_FLIP", x, PACKAGE = "hutilscpp")
+}
+
+
 do_par_in_hash_int <- finp
 do_par_in_hash_dbl <- finp
 
 # nocov start
-match_last_resort <- function(x, table, nomatch = NA_integer_, nThread = getOption("hutilscpp.nThread", 1L),
+match_last_resort <- function(x, table, nomatch = NA_integer_,
+                              nThread = getOption("hutilscpp.nThread", 1L),
                               fin = FALSE,
                               whichFirst = 0L) {
   if (isTRUE(fin)) {
@@ -66,10 +115,10 @@ match_last_resort <- function(x, table, nomatch = NA_integer_, nThread = getOpti
   }
   if (whichFirst) {
     if (whichFirst == 1L) {
-      first_which(x %in% table)
+      return(first_which(x %in% table))
     }
     if (whichFirst == -1L) {
-      last_which(x %in% table)
+      return(last_which(x %in% table))
     }
   }
   match(x, table, nomatch = nomatch)
